@@ -51,6 +51,7 @@ from calculate.lib.utils.portage import (ReposConf, EmergeLog,
                                          EmergeLogNamedTask,
                                          VDB_PATH,
                                          PackageInformation,
+                                         PortageState,
                                          get_packages_files_directory,
                                          get_manifest_files_directory,
                                          get_remove_list)
@@ -1723,3 +1724,13 @@ class Update(MethodsInterface):
                 except IOError as e:
                     self.printWARNING(str(e))
         return True
+
+    def save_portage_state_hash(self):
+        """
+        Сохранить состояние
+        """
+        ini = SystemIni(self.clVars)
+        ps = PortageState()
+        new_portage_state_hash = ps.get_state()
+        ini.setVar('system', {'portage_hash': new_portage_state_hash})
+        return True
