@@ -265,12 +265,24 @@ class ClUpdateAction(Action):
              'method': 'Update.premerge("-uDN","@world")',
              'condition': lambda Get: (
                  Get('cl_update_sync_only_set') == 'off' and
-                 Get('cl_update_pretend_set') == 'on')
+                 Get('cl_update_pretend_set') == 'on') and \
+                   (Get('cl_update_world') != "update" or
+                    Get('cl_update_outdate_set') == 'on' or
+                    Get('cl_update_settings_changes_set') == 'on' or
+                    Get('cl_update_binhost_recheck_set') == 'on' or
+                    Get('cl_update_force_fix_set') == 'on' or
+                    Get('update.cl_update_package_cache_set') == 'on')
             }],
          },
         {'name': 'update',
-         'condition': lambda Get:Get('cl_update_pretend_set') == 'off',
-         },
+         'condition': lambda Get:Get('cl_update_pretend_set') == 'off' and \
+                           (Get('cl_update_world') != "update" or
+                            Get('cl_update_outdate_set') == 'on' or
+                            Get('cl_update_settings_changes_set') == 'on' or
+                            Get('cl_update_binhost_recheck_set') == 'on' or
+                            Get('cl_update_force_fix_set') == 'on' or
+                            Get('update.cl_update_package_cache_set') == 'on')
+             },
         {'name': 'update_other',
          'condition': lambda Get: ( Get('cl_update_pretend_set') == 'off' and
                                     Get('cl_update_sync_only_set') == 'off')
@@ -413,6 +425,10 @@ class ClUpdateAction(Action):
          'depend': Tasks.failed_all("check_schedule")
          },
         # сообщение удачного завершения при обновлении ревизии
+        {'name': 'update:save_portage_hash',
+         'method': 'Update.save_portage_state_hash()',
+         },
+        # сообщение удачного завершения при обновлении ревизии
         {'name': 'success_rev',
          'message': __("System update finished!"),
          'condition': lambda Get: (Get('cl_update_rev_set') == 'on' and
